@@ -80,11 +80,8 @@ def fetch_taxon_info(tax_ids):
 
 ## Helper predicate function
 def ncbi_taxon_p(taxon_id):
-    tax_info = None
-    try:
-        tax_info = fetch_taxon_info([taxon_id])
-    finally:
-        return tax_info != None
+    ncbi = NCBITaxa(taxon_db_path)
+    return len(ncbi.get_rank([taxon_id])) > 0
 
 
 ## ToDo: figure out best way to serialize: JSON?
@@ -172,16 +169,23 @@ def load_metacyc_effective_orphan_reactions(orphan_file):
 
 ### Load in EggNOG annotation of proteins:
 
+## Print warnings about unrecognized taxon IDs from annotation file:
 def fetch_taxa_of_annotation(annot_file):
     tax_ids = []
+    present_tax_ids = []
     with open(annot_file) as annot_fh:
         for line in annot_fh:
             if not line.startswith('#'):
                 fields = line.strip().split('\t')
                 ogs = fields[18].split(',')
                 tax_ids.extend([ og.split('@')[1] for og in ogs ])
-    tax_ids = list(set(tax_ids))
-    return fetch_taxon_info(tax_ids)
+    for tax_id in set(tax_ids):
+        if not ncbi_taxon_p(tax_id):
+            print('Warning: Unable to find the following annotation file taxon ID in local NCBI Taxonomy DB (will be skippped): ' + str(tax_id), file = sys.stderr)
+        else:
+            present_tax_ids.append(tax_id)
+            #    tax_ids = list(set(tax_ids))
+    return fetch_taxon_info(present_tax_ids)
 
 
 ## There are a couple of ways that we can pick an annotation:
@@ -244,8 +248,8 @@ def select_most_specific_annotation(raw_ogs, nog2rxn_conn, annot_taxon2tuple):
     most_specific_og_dist = 0
     for og in raw_ogs:
         ##og_id = og.split('@')[0]
-        if len(ogs_in_db(nog2rxn_conn, og)) > 0:
-            og_taxon = og.split('@')[1]
+        og_taxon = og.split('@')[1]
+        if ncbi_taxon_p(og_taxon) and len(ogs_in_db(nog2rxn_conn, og)) > 0:
             if og_taxon in annot_taxon2tuple:
                 og_dist  = len(annot_taxon2tuple[og_taxon].lineage)
             else:
@@ -303,7 +307,7 @@ def map_filter_taxon2domain(org_taxon):
 
     
 def map_rank(rank, org_taxon, annot_taxon2tuple):
-    #print(rank, org_taxon, file=sys.stderr)
+    
     rank_order = ['superkingdom',
                   'phylum',
                   'class',
@@ -334,16 +338,15 @@ def map_rank(rank, org_taxon, annot_taxon2tuple):
     
 ## Reaction Prediction
 
-def mapOG2rxn(og, nog2rxn_conn, taxon2tuple, org_taxon, tax_restrict=True):
+def mapOG2rxn_tuples(og, nog2rxn_conn, taxon2tuple, org_taxon, tax_restrict=True):
     reactions = []
     og_tax_id = og.split('@')[1]
     if tax_restrict and \
        og_tax_id in taxon2tuple and \
        ncbi_taxon_subsumes_or_equal_p(org_taxon, taxon2tuple[og_tax_id]):
-        for rxn_map in ogs_in_db(nog2rxn_conn, og):
-            reactions.append(rxn_map['rxn'])    
+        reactions = ogs_in_db(nog2rxn_conn, og)
     
-    return list(set(reactions))
+    return reactions
 
 
 '''
@@ -371,7 +374,7 @@ def eggnog_annot2rxns(annot_struct,
                                  annot_taxon2tuple,
                                  annot_mode='most_specific')
     if not og:
-        return [], '', 'no OG found with associated reactions', []
+        return [], '', 'no OG found with associated reactions', '', ''
 
     
     #filter_taxon = map_filter_taxon2domain(org_taxon)
@@ -387,16 +390,16 @@ def eggnog_annot2rxns(annot_struct,
     #
     #filter_taxon = annot_taxon2tuple[ mapped_tax_id ]
     
-    reactions = mapOG2rxn(og,
-                          nog2rxn_conn,
-                          annot_taxon2tuple,                          
-                          mapped_taxon,
-                          tax_restrict=True)
+    reaction_tuples = mapOG2rxn_tuples(og,
+                                       nog2rxn_conn,
+                                       annot_taxon2tuple,                          
+                                       mapped_taxon,
+                                       tax_restrict=True)
     
     ## Remove instance reactions when subsuming generic reaction is present:
     ## No-op for now, premature optimization
     
-    return (reactions,
+    return (reaction_tuples,
             mapped_rank,
             mapped_taxon,
             annot_struct.prot_id,
