@@ -3,15 +3,16 @@ from __future__ import absolute_import
 from __future__ import division
 from builtins import str
 from past.utils import old_div
-from reactionary.reactionary_lib import load_eggnog_rxn_mapping_file, load_metacyc_effective_orphan_reactions, load_eggnog_annotation, mapOG2rxn, tax_dist2root, fetch_taxon_info, fetch_taxa_of_annotation, load_annot_file, eggnog_annot2rxns
-from reactionary.reactionary import coerce_taxonid_to_metacyc_taxon_frame, augment_eggnog_annotation
-from reactionary.warpath import predict_metacyc_pathways, predict_pathways
+from reactionary.reactionary_lib import load_eggnog_rxn_mapping_file, load_metacyc_effective_orphan_reactions, load_eggnog_annotation, mapOG2rxn_tuples, tax_dist2root, fetch_taxon_info, fetch_taxa_of_annotation, load_annot_file, eggnog_annot2rxns
+from reactionary.reactionary import coerce_taxonid_to_metacyc_taxon_frame, augment_eggnog_annotation, predict_pathways
+from reactionary.warpath import predict_metacyc_pathways
 
 from camelot_frs.camelot_frs import get_kb, get_frame, get_frames, get_frame_all_parents, get_frame_all_children, frame_parent_of_frame_p
 from camelot_frs.pgdb_loader import load_pgdb
 from camelot_frs.pgdb_api import uniprot_links_of_reaction, potential_generic_reaction_p, get_generic_reaction_all_subs, sub_reactions_of_reaction, enzymes_of_reaction, potential_pathway_hole_p, protein_complex_p, monomers_of_complex, get_dblinks, reactions_of_protein, complexes_of_monomer
 
 from Bio import Entrez
+from ete3 import NCBITaxa
 from collections import defaultdict, namedtuple
 from random import shuffle
 import sys, gzip, time, os, sqlite3
@@ -75,9 +76,13 @@ fn_rxns = list(set(fn_rxns) & set(bsub_env_list[0]))
 
 ### New workflow:
 
-env_tuple = load_env("/home/taltman/data/biocyc-24.0/meta/24.0/data")
+env_tuple = load_env("/home/taltman/data/biocyc-24.0/meta/24.0/data",'/home/taltman/data/')
 
-bsub_env_list = load_pgdb_env("/home/taltman/data/biocyc-24.0/bsub/42/data", 'BSUB', '/home/taltman/repos/reactionary/test/bsub-24-0-annot.emapper.annotations', env_tuple.eggnog2rxns, env_tuple.orphan_dict)
+# ECOLI:
+ecoli_env_list = load_pgdb_env('/home/taltman/data/biocyc-24.0/ecoli/24.0/data', 'ECOLI', '/home/taltman/repos/reactionary/test/ecoli-24-0-annot.emapper-annotations', env_tuple.orphan_dict, env_tuple.nog2rxn_conn)
+
+# BSUB
+bsub_env_list = load_pgdb_env("/home/taltman/data/biocyc-24.0/bsub/42/data", 'BSUB', '/home/taltman/repos/reactionary/test/bsub-24-0-annot.emapper.annotations', env_tuple.orphan_dict, env_tuple.nog2rxn_conn)
 
 '''
 
@@ -658,6 +663,80 @@ def load_pgdb_env(pgdb_dir, org_id, annot_file, orphan_dict, nog2rxn_conn):
 
 ### Print PGDB report, comparing Reactionary pathway predictions to PGDB pathways for a select set of pathway classes:
 
+def get_warpath_pwys(taxon_id,
+                     annot_path,
+                     conn,
+                     enclosing_rank):
+
+    output_dir = '/tmp'
+    ncbi_taxon_tuple = fetch_taxon_info([taxon_id])[taxon_id]
+    taxon2tuple = fetch_taxa_of_annotation(annot_path)
+    rxn2annot = augment_eggnog_annotation(annot_path,
+                                          taxon2tuple,
+                                          ncbi_taxon_tuple,
+                                          conn,
+                                          output_dir,
+                                          max_rxns = 10,
+                                          enclosing_rank = enclosing_rank)
+    annotated_eggnog_file = output_dir + '/' + \
+                            os.path.basename(annot_path)+'.reactionary'
+    pwy_pred_results, _ = predict_pathways(annotated_eggnog_file,
+                                           ncbi_taxon_tuple,
+                                           output_dir)
+    return pwy_pred_results, rxn2annot
+
+def warpath_vs_pgdb_roc(taxon_id, predicted_pwys, pgdb, metaKB):
+    for threshold in range(0,105,5):
+        f1, precision, recall, \
+            tp, fp, fn = warpath_vs_pgdb_stats(taxon_id,
+                                               predicted_pwys,
+                                               threshold/100,
+                                               pgdb,
+                                               metaKB)
+        print(f'{f1:.2f}\t{precision:.2f}\t{recall:.2f}\t{tp}\t{fp}\t{fn}')
+              
+
+def eval_pwy_pred_p(taxon_id, pwy_pred, threshold):
+    ncbi = NCBITaxa('/home/taltman/data/taxa.sqlite')
+    tax_domain_p = len(set([str(tax_id) for tax_id in ncbi.get_lineage(taxon_id)]) & set(pwy_pred[3])) > 0
+    pwy_p = tax_domain_p and pwy_pred[2] >= threshold
+    if pwy_pred[6] != None:
+        pwy_p = pwy_p and pwy_pred[6]
+    if pwy_pred[8] != None:
+        pwy_p = pwy_p and pwy_pred[8]
+    
+    return pwy_p
+    
+def warpath_vs_pgdb_stats(taxon_id, predicted_pwys, threshold, pgdb, metaKB):
+    pwy_class = get_frame(metaKB, 'Pathways')
+    super_pwy_class = get_frame(metaKB, 'Super-Pathways')
+    predictable_pwys = [ pwy.frame_id
+                         for pwy in get_frame_all_children(pwy_class, frame_types='instance')
+                         if super_pwy_class not in pwy.get_frame_parents() ]
+    pwy_class = get_frame(pgdb, 'Pathways')
+    super_pwy_class = get_frame(pgdb, 'Super-Pathways')
+    ecoli_predictable_pwys = [ pwy.frame_id
+                               for pwy in get_frame_all_children(pwy_class, frame_types='instance')
+                               if super_pwy_class not in pwy.get_frame_parents() ]
+
+    predicted_pwy_ids = [ pred[0] for pred in predicted_pwys if eval_pwy_pred_p(taxon_id,
+                                                                                pred,
+                                                                                threshold) ]
+
+    true_positives  = set(ecoli_predictable_pwys) & set(predicted_pwy_ids)
+    false_positives = set(predicted_pwy_ids) - set(ecoli_predictable_pwys)
+    false_negatives = set(ecoli_predictable_pwys) - set(predicted_pwy_ids)
+    precision = len(true_positives)/len(predicted_pwy_ids)
+    recall    = len(true_positives)/len(ecoli_predictable_pwys)
+    f1_score = 2.0*precision*recall/(precision+recall)
+    return (f1_score,
+            precision,
+            recall,
+            len(true_positives),
+            len(false_positives),
+            len(false_negatives))
+
+
 def warpath_vs_pgdb_pwys_report(env_tuple,
                                 pgdb_dir,
                                 org_id,
